@@ -13,13 +13,13 @@ Versioning semantics:
 
 """
 
-__intname__ = 'ofunctions.checksums'
-__author__ = 'Orsiris de Jong'
-__copyright__ = 'Copyright (C) 2019-2021 Orsiris de Jong'
-__description__ = 'SHA256 Checksumming functions, checksum manifest file creation and verification'
-__licence__ = 'BSD 3 Clause'
-__version__ = '0.3.0'
-__build__ = '2021052601'
+__intname__ = "ofunctions.checksums"
+__author__ = "Orsiris de Jong"
+__copyright__ = "Copyright (C) 2019-2021 Orsiris de Jong"
+__description__ = "SHA256 Checksumming, manifest file creation and verification"
+__licence__ = "BSD 3 Clause"
+__version__ = "0.3.0"
+__build__ = "2021052601"
 
 
 import os
@@ -38,7 +38,7 @@ def sha256sum(file: str) -> str:
     sha256 = hashlib.sha256()
 
     try:
-        with open(file, 'rb') as file_handle:
+        with open(file, "rb") as file_handle:
             while True:
                 data = file_handle.read(65536)
                 if not data:
@@ -64,13 +64,17 @@ def check_file_hash(file: str, hashsum: str) -> bool:
         if hashsum == calculated_hashsum:
             return True
 
-        raise ValueError('File "%s" has an invalid sha256sum "%s". Reference sum is "%s".'
-                         % (file, calculated_hashsum, hashsum))
+        raise ValueError(
+            'File "%s" has an invalid sha256sum "%s". Reference sum is "%s".'
+            % (file, calculated_hashsum, hashsum)
+        )
 
     return False
 
 
-def create_sha256sum_file(directory: str, sumfile: str = 'SHA256SUMS.TXT', depth: int = 1) -> None:
+def create_sha256sum_file(
+    directory: str, sumfile: str = "SHA256SUMS.TXT", depth: int = 1
+) -> None:
     """
     Create a checksum file for a given directory
     This function creates the file on the fly bacause we yield results
@@ -85,14 +89,16 @@ def create_sha256sum_file(directory: str, sumfile: str = 'SHA256SUMS.TXT', depth
     files = get_paths_recursive(directory, exclude_dirs=True, max_depth=depth)
     try:
         sumfile = os.path.join(directory, sumfile)
-        with open(sumfile, 'w', encoding='utf-8') as file_handle:
-            file_handle.write('# Generated on %s UTC\n\n' % datetime.utcnow())
+        with open(sumfile, "w", encoding="utf-8") as file_handle:
+            file_handle.write("# Generated on %s UTC\n\n" % datetime.utcnow())
 
             def _get_file_sum(files):
                 for file in files:
                     if file != sumfile:
                         sha256 = sha256sum(file)
-                        yield '{}  {}\n'.format(sha256, os.path.relpath(file, directory))
+                        yield "{}  {}\n".format(
+                            sha256, os.path.relpath(file, directory)
+                        )
 
             for line in _get_file_sum(files):
                 file_handle.write(line)
@@ -110,15 +116,20 @@ def create_manifest_from_dict(manifest_file: str, manifest_dict: dict) -> None:
     :return:
     """
     try:
-        with open(manifest_file, 'w', encoding='utf-8') as file_handle:
+        with open(manifest_file, "w", encoding="utf-8") as file_handle:
             for key, value in manifest_dict.items():
-                file_handle.write('{}  {}\n'.format(key, value))
+                file_handle.write("{}  {}\n".format(key, value))
     except IOError:
         raise IOError('Cannot write manifest file "%s".' % manifest_file) from IOError
 
 
-def create_manifest_from_dir(manifest_file: str, path: str, remove_prefixes: list = None,
-                             f_exclude_list: list = None, d_exclude_list: list = None) -> None:
+def create_manifest_from_dir(
+    manifest_file: str,
+    path: str,
+    remove_prefixes: list = None,
+    f_exclude_list: list = None,
+    d_exclude_list: list = None,
+) -> None:
     """
     Creates a bash like file manifest with sha256sum and filenames
     Just like create_sha256sum_file() except we keep full paths and may remove prefixes
@@ -132,13 +143,18 @@ def create_manifest_from_dir(manifest_file: str, path: str, remove_prefixes: lis
     :return:
     """
     if not os.path.isdir(path):
-        raise NotADirectoryError('Path [%s] does not exist.' % path)
+        raise NotADirectoryError("Path [%s] does not exist." % path)
 
-    files = get_paths_recursive(path, f_exclude_list=f_exclude_list, d_exclude_list=d_exclude_list, exclude_dirs=True)
-    with open(manifest_file, 'w', encoding='utf-8') as file_handle:
+    files = get_paths_recursive(
+        path,
+        f_exclude_list=f_exclude_list,
+        d_exclude_list=d_exclude_list,
+        exclude_dirs=True,
+    )
+    with open(manifest_file, "w", encoding="utf-8") as file_handle:
         for file in files:
             sha256 = sha256sum(file)
             for prefix in remove_prefixes if remove_prefixes is not None else []:
                 if file.startswith(prefix):
-                    file = file[len(prefix):].lstrip(os.sep)
-            file_handle.write('{}  {}\n'.format(sha256, file))
+                    file = file[len(prefix) :].lstrip(os.sep)
+            file_handle.write("{}  {}\n".format(sha256, file))
